;------------------------------------------------------------------------------
; Minitestprogramm zum schaltbaren ROM-Modul
;
; Zwei Kommandos "F8" und "FC" werden nach 1000h kopiert
; Die Kommandos schreiben auf Adresse F800 bzw. FC00
; und zeigen den Speicherinhalt der Adresse C000-C07F zu Kontrolle an
; F8 - schaltbares ROM-Modul ein, (auch nach Reset)
; FC - schaltbares ROM-Modul aus, es ist dann der BASIC-ROM zu sehen
;
; 11.02.2009 V.Pohlers
;------------------------------------------------------------------------------

	cpu	z80

OCRLF:	EQU	0F2FEH
OUTA:	EQU	0F305H
OSPAC:	EQU	0F310H
PRNST:	EQU	0F3E2H		;Stringausgabe

	org 	0C000h

anf:
	jp	eos		; OS-Erweiterung
	db "#       ",0
	db    0

;------------------------------------------------------------------------------
; "#       " OS-Erweiterung
;------------------------------------------------------------------------------

aEos:	db 0Bh,14h,1,"EOS",14h,2,0Ah
	db 0Dh,0

eos:	
; Umkopieren	
	ld	hl, anf0
	ld	de, 1000h
	ld	bc, end0-anf0
	ldir
; systemmeldung
	ld	de, aEos	; "\v\x14\x01EOS\x14\x02\n\r"
	CALL	PRNST		;Ausgabe Text
	jp	0F089h
;


anf0

;------------------------------------------------------------------------------
; F8, FC
;------------------------------------------------------------------------------

	phase	1000h

	jp	f8
	db "F8      ",0
	jp	fc
	db "FC      ",0
	db	0

F8:	ld	bc, 0f800h
	jr	FC1
FC:	ld	bc, 0fc00h	
FC1:	ld      (bc), a		; ROM ein/aus je nachdem, welche Adr. in BC steht


;------------------------------------------------------------------------------
; Display Bereich ab C000h zur Visualisierung
;------------------------------------------------------------------------------

	LD	HL, 0c000h
	LD	C,8		;Zeilenanzahl
RAM1:	LD	B,8
	PUSH	HL
	CALL	OUTHL		;Anzeige Adresse
	CALL	OSPAC
	CALL	OSPAC
RAM3:	LD	A,(HL)
	CALL	OUTHX		;Ausgabe Byte
	CALL	OSPAC
	INC	HL
	DJNZ	RAM3
	CALL	OSPAC
	POP	HL
	LD	B,8
	CALL	COOUT		;Ausgabe ASCII
	CALL	OCRLF		;neue Zeile
	DEC	C
	JR	NZ, RAM1
	XOR	A
	RET
;


;OUTHL Ausgabe (HL) hexa
OUTHL:	LD	A,H
	CALL	OUTHX
	LD	A,L
;OUTHX Ausgabe (A) hexa
OUTHX:	PUSH	AF
	RLCA
	RLCA
	RLCA
	RLCA
	CALL	OUTH1
	POP	AF
OUTH1:	AND	A, 0FH
	ADD	A, 30H
	CP	A, 3AH
	JR	C, OUTH2
	ADD	A, 07H
OUTH2:	CALL	OUTA
	RET
;
;COOUT Ausgabe ab (HL) (B) Zeichen, nur Buchstaben
COOUT:	LD	A,(HL)
	CP	A, ' '
	JR	NC, COUT1
	LD	A,' '
COUT1:	CALL	OUTA		;Zeichen ausgeben
	INC	HL
	DJNZ	COOUT
	RET

	dephase

;------------------------------------------------------------------------------
; 
;------------------------------------------------------------------------------

end0

	ds	0C800h-1-$
	db	0ffh
	
	end
